@@ -1,6 +1,3 @@
-#[macro_use]
-extern crate failure;
-
 #[cfg_attr(test, macro_use)]
 extern crate lazy_static;
 
@@ -9,8 +6,6 @@ extern crate serde_derive;
 
 #[cfg(test)]
 extern crate siphasher;
-#[macro_use]
-extern crate xfailure;
 
 mod errors;
 mod functions_ids;
